@@ -13,7 +13,7 @@
  * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
  */
 
-/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */
+/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
 
 /******************************************************************************
  * MAIN
@@ -67,8 +67,8 @@ function show_order_details($id) {
 
 	$qid_order = db_query("
 	SELECT o.*, os.name AS state_name
-	FROM orderscc o JOIN orders_states os ON (o.state_id = os.id)
-	WHERE o.id = '$id'
+	FROM orderscc o, orders_states os
+	WHERE o.state_id = os.id AND o.id = '$id'
 	");
 	$qid_items = db_query("
 	SELECT
@@ -80,8 +80,8 @@ function show_order_details($id) {
 		,oi.weight AS purchase_weight
 		,oi.qty
 		,oi.price * oi.qty AS total
-	FROM	order_items oi JOIN products p ON (oi.product_id = p.id)
-	WHERE	order_id = '$id'
+	FROM	order_items oi, products p
+	WHERE	oi.product_id = p.id AND order_id = '$id'
 	UNION
 	SELECT
 		 oi.product_id
@@ -102,6 +102,21 @@ function show_order_details($id) {
 			WHERE id = oi.product_id
 		)
 	");
+/* For MySQL
+	$qid_items = db_query("
+	SELECT
+		 oi.product_id
+		,p.name
+		,p.price AS curr_price
+		,oi.price AS purchase_price
+		,oi.iva AS purchase_iva
+		,oi.weight AS purchase_weight
+		,oi.qty
+		,oi.price * oi.qty AS total
+	FROM	order_items oi LEFT JOIN products p ON (oi.product_id = p.id)
+	WHERE	order_id = '$id'
+	");
+*/
 
 	$order = db_fetch_object($qid_order, 0);
 
@@ -145,8 +160,8 @@ function print_edit_order_form($id) {
 		,oi.weight AS purchase_weight
 		,oi.qty
 		,oi.price * oi.qty AS total
-	FROM	order_items oi JOIN products p ON (oi.product_id = p.id)
-	WHERE	order_id = '$id'
+	FROM	order_items oi, products p
+	WHERE	oi.product_id = p.id AND order_id = '$id'
 	UNION
 	SELECT
 		 oi.product_id
@@ -167,6 +182,21 @@ function print_edit_order_form($id) {
 			WHERE id = oi.product_id
 		)
 	");
+/* For MySQL
+	$qid_items = db_query("
+	SELECT
+		 oi.product_id
+		,p.name
+		,p.price AS curr_price
+		,oi.price AS purchase_price
+		,oi.iva AS purchase_iva
+		,oi.weight AS purchase_weight
+		,oi.qty
+		,oi.price * oi.qty AS total
+	FROM	order_items oi LEFT JOIN products p ON (oi.product_id = p.id)
+	WHERE	order_id = '$id'
+	");
+*/
 
 	$qid_user = db_query("
 	SELECT usertype, fiscalcode, email
@@ -223,7 +253,8 @@ function print_order_list() {
 	if (!isset($page_number) || $dbchanged) {
 		$qid = db_query("
 		SELECT o.id, o.username, o.date, o.custinfo, o.amount, o.notes, os.name AS state_name
-		FROM orderscc o JOIN orders_states os ON (o.state_id = os.id)
+		FROM orderscc o, orders_states os
+		WHERE o.state_id = os.id
 		ORDER BY os.name, o.id ASC
   		");
 
