@@ -12,13 +12,11 @@
  * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
  */
 
-/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */
+/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
 
 /* turn on verbose error reporting (15) to see all warnings and errors */
 //error_reporting(15);
 
-$special_th = 100;
-
 /* define a generic object */
 class object {};
 
@@ -31,13 +29,14 @@ $CFG->dbname = "pgmarket";
 $CFG->dbuser = "postgres";
 $CFG->dbpass = "postgres";
 
-$CFG->myname = "PgMarket 1.3.x";
+$CFG->myname = "PgMarket 1.4.1";
 
 $CFG->wwwroot     = "/~pratesi/pgmarket";	// without an ending "/"
 $CFG->firstpage   = "$CFG->wwwroot/firstpage.php";
 $CFG->dirroot     = "/home/pratesi/public_html/pgmarket";	// without an ending "/"
 $CFG->templatedir = "$CFG->dirroot/templates/";	// with an ending "/"
 $CFG->libdir      = "$CFG->dirroot/lib";	// without an ending "/"
+$CFG->libwww      = "$CFG->wwwroot/lib";	// without an ending "/"
 $CFG->localedir   = "$CFG->dirroot/locale/";	// with an ending "/"
 $CFG->productswww = "$CFG->wwwroot/products/";	// with an ending "/"
 $CFG->productsdir = "$CFG->dirroot/products/";	// with an ending "/"
@@ -78,22 +77,21 @@ if (! isset($SESSION)) {
 }
 
 // Loaded modules
-$SESSION["frames_used"] = 1;
-$SESSION["catbrowser_target"] = "bodyframe";
-//$SESSION["frames_used"] = 0;
-//$SESSION["catbrowser_target"] = "main";
-$SESSION["layersmenu_used"] = 1;
+if (! isset($SESSION["frames_used"])) {
+	$SESSION["frames_used"] = 1;
+	$SESSION["catbrowser_target"] = "bodyframe";
+//	$SESSION["frames_used"] = 0;
+//	$SESSION["catbrowser_target"] = "main";
+}
+if (! isset($SESSION["layersmenu_used"]))
+	$SESSION["layersmenu_used"] = 1;
 $SESSION["brand_used"] = 1;
 $SESSION["iva_used"] = 1;
 //$SESSION["iva_value"] = 0;	// not significant if IVA is used
+$IVA = "IVA";
 $SESSION["weight_used"] = 1;
 $SESSION["delivery_used"] = 1;
 
-$SESSION["price_must_be_integer"] = 1;
-	// 1 --> the price must be integer (Italian Lit, for example)
-	// 0 --> the price can be float (US Dollars, for example)
-$SESSION["weightmax"] = 10000.0;
-
 $SESSION["max_file_size_import"] = 10000000;	// upload of import files
 $SESSION["max_file_size_images"] = 500000;	// upload of product images
 
@@ -115,29 +113,33 @@ $CFG->global = $CFG->localedir.$SESSION["lang"]."/global.inc.php";
 
 include ($CFG->global);
 
-$dollars = "Lit";
+$currency = "Lit";
 $lire2euro = 1936.27;
-//$dollars = "$";
+//$currency = "$";
+$SESSION["price_must_be_integer"] = 1;
+	// 1 --> the price must be integer (Italian Lit, for example)
+	// 0 --> the price can be float (US Dollars, for example)
 function print_formatted_price($price) {
-	global $dollars, $lire2euro;
-	echo $dollars . " " . number_format ($price, 0, ",", ".") . "<br>&euro; " . number_format ($price/$lire2euro, 2, ",", ".");
-//	echo $dollars . " " . number_format ($price, 0, ",", ".");
-//	echo $dollars . " " . number_format ($price, 2, ".", ",");
+	global $currency, $lire2euro;
+	echo $currency . " " . number_format ($price, 0, ",", ".") . "<br>&euro; " . number_format ($price/$lire2euro, 2, ",", ".");
+//	echo $currency . " " . number_format ($price, 0, ",", ".");
+//	echo $currency . " " . number_format ($price, 2, ".", ",");
 }
 function formatted_price($price) {
-	global $dollars, $lire2euro;
-	return $dollars . " " . number_format ($price, 0, ",", ".") . "<br>&euro; " . number_format ($price/$lire2euro, 2, ",", ".");
-//	return $dollars . " " . number_format ($price, 0, ",", ".");
-//	return $dollars . " " . number_format ($price, 2, ".", ",");
+	global $currency, $lire2euro;
+	return $currency . " " . number_format ($price, 0, ",", ".") . "<br>&euro; " . number_format ($price/$lire2euro, 2, ",", ".");
+//	return $currency . " " . number_format ($price, 0, ",", ".");
+//	return $currency . " " . number_format ($price, 2, ".", ",");
 }
 function formatted_price_text($price) {
-	global $dollars, $lire2euro;
-	return $dollars . " " . number_format ($price, 0, ",", ".") . " - Euro " . number_format ($price/$lire2euro, 2, ",", ".");
-//	return $dollars . " " . number_format ($price, 0, ",", ".");
-//	return $dollars . " " . number_format ($price, 2, ".", ",");
+	global $currency, $lire2euro;
+	return $currency . " " . number_format ($price, 0, ",", ".") . " - Euro " . number_format ($price/$lire2euro, 2, ",", ".");
+//	return $currency . " " . number_format ($price, 0, ",", ".");
+//	return $currency . " " . number_format ($price, 2, ".", ",");
 }
 
 $weightunity = "Kg";
+$SESSION["weightmax"] = 10000.0;
 function print_formatted_weight($weight) {
 	echo number_format ($weight, 2, ",", ".");
 //	echo number_format ($weight, 2, ".", ",");
@@ -159,7 +161,7 @@ $SESSION["partitaiva_length"] = 11;
 $SESSION["address_length"] = 255;
 $SESSION["number_length"] = 5;
 $SESSION["city_length"] = 100;
-$SESSION["state_length"] = 100;
+$SESSION["country_length"] = 100;
 $SESSION["zip_code_length"] = 5;
 $SESSION["phone_length"] = 32;
 $SESSION["phone_length_min"] = 5;
@@ -182,6 +184,8 @@ $SESSION["product_name_length"] = 100;
 $SESSION["product_description_length"] = 500;
 $SESSION["product_extended_description_length"] = 2000;
 $SESSION["discqtymax"] = 1000;
+$SESSION["order_state_name_length"] = 100;
+$SESSION["order_state_description_length"] = 255;
 
 $SESSION["products_per_page"] = 10;	// max number of products to be shown per page (search results, admin products page)
 $SESSION["max_results"] = 100;		// max number of search results to accept the search request
@@ -189,7 +193,8 @@ $SESSION["users_per_page"] = 10;	// max number of users to be shown per page (ad
 $SESSION["orders_per_page"] = 10;	// max number of orders to be shown per page (admin orders page)
 $SESSION["categories_per_page"] = 10;	// max number of categories to be shown per page (admin categories page)
 $SESSION["brands_per_page"] = 10;	// max number of brands to be shown per page (admin brands page)
-$SESSION["iva_per_page"] = 10;		// max number of iva percentuals to be shown per page (admin iva page)
+$SESSION["iva_per_page"] = 10;		// max number of iva percentages to be shown per page (admin iva page)
+$SESSION["orders_states_per_page"] = 10; // max number of orders states to be shown per page (admin orders state page)
 
 $ordersdb[Customer]	= "Cliente             :";
 $ordersdb[Phone]	= "Recapito telefonico :";
@@ -205,7 +210,7 @@ $ordersdb[Unit_Price] = "Prezzo unitario";
 $ordersdb[Number_of_items] = "Numero di pezzi";
 $ordersdb[Delivery] = "Spedizione";
 
-$contact[NameOrEnterpriseName] = "Nome (Ragione Sociale): ";
+$contact[NameOrCompanyName] = "Nome (Ragione Sociale): ";
 $contact[Address] = "Indirizzo:";
 $contact[Phone]         = "Telefono:  ";
 $contact[Fax]           = "Fax:       ";
@@ -222,7 +227,7 @@ $myday[4] = "Giovedi";
 $myday[5] = "Venerdi";
 $myday[6] = "Sabato";
 $myday[0] = "Domenica";
-        
+
 $mymonth[1] = "Gennaio";
 $mymonth[2] = "Febbraio";
 $mymonth[3] = "Marzo";
