@@ -35,6 +35,9 @@ if (match_referer() && isset($HTTP_POST_VARS) && !isset($from_menu)) {
 		include("$CFG->templatedir"."footer.ihtml");
 		die;
 	}
+
+	if ($HTTP_POST_VARS["hiddencountry"] == "it")
+		$country = "it";
 }
 
 $DOC_TITLE = $Signup;
@@ -70,7 +73,7 @@ function validate_form(&$frm, &$errors, $usertype) {
 	if ($usertype == "pf") {
 		validate_firstname($frm["firstname"], &$errors, &$msg);
 		validate_lastname($frm["lastname"], &$errors, &$msg);
-		if ($frm["country"] == "it") {
+		if ($frm["hiddencountry"] == "it") {
 			validate_fiscalcode($frm["fiscalcode"], &$errors, &$msg);
 		}
 	} else if ($usertype == "az") {
